package de.bsvrz.sys.usv.enums;

/**
 * Zuordnung der Zustnde des Attributs BatterieZustand der Attributgruppe
 * atg.usvStatus
 * 
 * @author ObertM
 * @author Christian Hsel, BitCtrl Systems GmbH
 * 
 */
public enum BatterieZustand {

	/**
	 * Der {@link BatterieZustand} "Nicht ermittelbar" (-1).
	 */
	na("nicht ermittelbar", -1);

	private final String m_text;
	private final int m_value;

	/**
	 * Privater Konstruktor zur Erzeugung eines {@link BatterieZustand}es.
	 * 
	 * @param text
	 *            der Name des {@link BatterieZustand}es.
	 * @param value
	 *            die Ordinalzahl des {@link BatterieZustand}es.
	 */
	private BatterieZustand(final String text, final int value) {
		m_text = text;
		m_value = value;
	}

	/**
	 * Sucht eine {@link BatterieZustand} entsprechend des bergebenen Namens.
	 * 
	 * @param name
	 *            der Name des gesuchten {@link BatterieZustand}es.
	 * @return den entsprechenden {@link BatterieZustand}, oder
	 *         <code>null<code>, falls kein Zustand mit dem gesuchten Namen existiert.
	 */
	public static final BatterieZustand findBatterieZustand(final String name) {
		for (final BatterieZustand zustand : BatterieZustand.values()) {
			if (zustand.getText().equals(name)) {
				return zustand;
			}
		}
		return null;
	}

	/**
	 * Sucht den {@link BatterieZustand} entsprechend der bergebenen
	 * Ordinalzahl.
	 * 
	 * @param value
	 *            die Ordinalzahl des gesuchten {@link BatterieZustand}es.
	 * @return den entsprechenden {@link BatterieZustand} oder <code>null</code>,
	 *         falls kein Zustand mit der gesuchten Ordinatzahl existiert. Das
	 *         sollte damit immer der Fall sein, wenn sich der Ladezustand der
	 *         Batterie zwischen 0..100% befindet.
	 */
	public static final BatterieZustand findBatterieZustand(final int value) {
		for (final BatterieZustand zustand : BatterieZustand.values()) {
			if (zustand.getValue() == value) {
				return zustand;
			}
		}
		return null;
	}

	/**
	 * Liefert den Namen des {@link BatterieZustand}es.
	 * 
	 * @return der Name des {@link BatterieZustand}es.
	 */
	public String getText() {
		return m_text;
	}

	/**
	 * Liefert die Ordinalzahl des {@link BatterieZustand}es.
	 * 
	 * @return die Ordinalzahl des {@link BatterieZustand}es.
	 */
	public int getValue() {
		return m_value;
	}
}
